@@ -19,12 +19,17 @@
 # with Crate these terms will supersede the license and you may use the
 # software solely pursuant to the terms of the relevant commercial agreement.
 
-from .connection import connect
+from .connection import Connection as connect
 from .exceptions import Error
 
+__all__ = [
+    connect,
+    Error,
+]
+
 # version string read from setup.py using a regex. Take care not to break the
 # regex!
-__version__ = "0.10.4"
+__version__ = "0.29.0"
 
 apilevel = "2.0"
 threadsafety = 2
